@@ -1,12 +1,13 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
+from datetime import timedelta
+import numpy as np
 import pandas as pd
-from covsirphy.util.error import SubsetNotFoundError
 from covsirphy.util.argument import find_args
 from covsirphy.cleaning.jhu_data import JHUData
 from covsirphy.ode.mbase import ModelBase
-from covsirphy.simulation.simulator import ODESimulator
+from covsirphy.ode.ode_handler import ODEHandler
 
 
 class ExampleData(JHUData):
@@ -34,15 +35,13 @@ class ExampleData(JHUData):
     def __init__(self, clean_df=None, tau=1440, start_date="22Jan2020"):
         if clean_df is None:
             clean_df = pd.DataFrame(columns=self.COLUMNS)
-        clean_df = self._ensure_dataframe(
-            clean_df, name="clean_df", columns=self.COLUMNS)
+        clean_df = self._ensure_dataframe(clean_df, name="clean_df", columns=self.COLUMNS)
         self._raw = clean_df.copy()
         self._cleaned_df = clean_df.copy()
         self._citation = str()
-        self.tau = self._ensure_tau(tau)
-        self.start_date = self._ensure_date(start_date, name="start_date")
-        self._specialized_dict = {}
-        self.nondim_dict = {}
+        self._tau = self._ensure_tau(tau)
+        self._start = self._ensure_date(start_date, name="start_date")
+        self._population = None
         self._recovery_period = None
 
     def _model_to_area(self, model=None, country=None, province=None):
@@ -88,48 +87,35 @@ class ExampleData(JHUData):
         model = self._ensure_subclass(model, ModelBase, name="model")
         arg_dict = model.EXAMPLE.copy()
         arg_dict.update(kwargs)
-        population = arg_dict["population"]
+        self._population = arg_dict["population"]
         # Area
-        country, province = self._model_to_area(
-            model=model, country=country, province=province)
+        country, province = self._model_to_area(model=model, country=country, province=province)
         # Start date and y0 values
         df = self._cleaned_df.copy()
-        df = df.loc[
-            (df[self.COUNTRY] == country) & (df[self.PROVINCE] == province), :
-        ]
+        df = df.loc[(df[self.COUNTRY] == country) & (df[self.PROVINCE] == province), :]
         if df.empty:
-            start_date = self.start_date
+            start = self._start
         else:
-            start_date = df.loc[
-                df.index[-1], self.DATE].strftime(self.DATE_FORMAT)
-            df = model.tau_free(df, population, tau=None)
-            arg_dict[self.Y0_DICT] = {
-                k: df.loc[df.index[0], k] for k in model.VARIABLES
-            }
+            start = df.loc[df.index[-1], self.DATE]
+            df[self.S] = self._population - df[self.C]
+            df = model.convert(df, tau=None)
+            arg_dict[self.Y0_DICT] = {k: df.loc[df.index[0], k] for k in model.VARIABLES}
         # Simulation
-        simulator = ODESimulator(country=country, province=province)
-        simulator.add(model=model, **arg_dict)
-        # Specialized records
-        dim_df = simulator.dim(tau=self.tau, start_date=start_date)
-        if country not in self._specialized_dict:
-            self._specialized_dict[country] = {}
-        self._specialized_dict[country][province] = dim_df.copy()
+        end = start + timedelta(days=int(arg_dict[self.STEP_N] * self._tau / 1440))
+        handler = ODEHandler(model, start, tau=self._tau)
+        handler.add(end, param_dict=arg_dict[self.PARAM_DICT], y0_dict=arg_dict[self.Y0_DICT])
+        restored_df = handler.simulate()
         # JHU-type records
-        restored_df = model.restore(dim_df)
         restored_df[self.COUNTRY] = country
         restored_df[self.PROVINCE] = province
+        restored_df[self.C] = restored_df[[self.CI, self.F, self.R]].sum(axis=1)
         selected_df = restored_df.loc[:, self.COLUMNS]
-        self._cleaned_df = pd.concat(
-            [self._cleaned_df, selected_df], axis=0, ignore_index=True
-        )
-        # Set non-dimensional data
-        if country not in self.nondim_dict:
-            self.nondim_dict[country] = {}
-        nondim_df = simulator.non_dim()
-        if province in self.nondim_dict[country]:
-            nondim_df_old = self.nondim_dict[country][province].copy()
-            nondim_df = pd.concat([nondim_df_old, nondim_df], axis=0)
-        self.nondim_dict[country][province] = nondim_df.copy()
+        cleaned_df = pd.concat([self._cleaned_df, selected_df], axis=0, ignore_index=True)
+        for col in self.AREA_COLUMNS:
+            cleaned_df[col] = cleaned_df[col].astype("category")
+        for col in self.VALUE_COLUMNS:
+            cleaned_df[col] = cleaned_df[col].astype(np.int64)
+        self._cleaned_df = cleaned_df.copy()
 
     def specialized(self, model=None, country=None, province=None):
         """
@@ -140,16 +126,21 @@ class ExampleData(JHUData):
             country (str or None): country name
             province (str or None): province name
 
+        Returns:
+            pandas.DataFrame:
+                Index
+                    reset index
+                Columns
+                    - Date (pd.Timestamp): Observation date
+                    - (int) variables of the model
+
         Note:
             If country is None, the name of the model will be used.
             If province is None, '-' will be used.
         """
-        country, province = self._model_to_area(
-            model=model, country=country, province=province)
-        try:
-            return self._specialized_dict[country][province]
-        except KeyError:
-            raise SubsetNotFoundError(country=country, province=province)
+        restored_df = self.subset(model=model, country=country, province=province)
+        restored_df[self.S] = self._population - restored_df[self.C]
+        return model.convert(restored_df, tau=None).reset_index()
 
     def non_dim(self, model=None, country=None, province=None):
         """
@@ -160,16 +151,21 @@ class ExampleData(JHUData):
             country (str or None): country name
             province (str or None): province name
 
+        Returns:
+            pandas.DataFrame:
+                Index
+                    t: Dates divided by tau value (time steps)
+                Columns
+                    - (int) variables of the model
+
         Note:
             If country is None, the name of the model will be used.
             If province is None, '-' will be used.
         """
-        country, province = self._model_to_area(
-            model=model, country=country, province=province)
-        try:
-            return self.nondim_dict[country][province]
-        except KeyError:
-            raise SubsetNotFoundError(country=country, province=province)
+        restored_df = self.subset(model=model, country=country, province=province)
+        restored_df[self.S] = self._population - restored_df[self.C]
+        df = model.convert(restored_df, tau=self._tau)
+        return df.apply(lambda x: x / x.sum(), axis=1)
 
     def subset(self, model=None, country=None, province=None, **kwargs):
         """
@@ -199,8 +195,8 @@ class ExampleData(JHUData):
             If @population is not None, the number of susceptible cases will be calculated.
             Records with Recovered > 0 will be selected.
         """
-        country, _ = self._model_to_area(
-            model=model, country=country, province=province)
+        country, _ = self._model_to_area(model=model, country=country, province=province)
+        kwargs["population"] = self._population
         kwargs = find_args([super().subset], **kwargs)
         return super().subset(country=country, province=province, **kwargs)
 
