@@ -1236,7 +1236,7 @@ class Scenario(Term):
         delay_period = int((low_lim + Q1) / 2)
         return (int(delay_period), df)
 
-    def fit(self, oxcgrt_data=None, name="Main", delay=(7, 31), removed_cols=None, metric="R2", **kwargs):
+    def fit(self, oxcgrt_data=None, name="Main", delay=(7, 31), removed_cols=None, metric="MAPE", **kwargs):
         """
         Fit regressors to predict the parameter values in the future phases,
         assuming that indicators will impact on ODE parameter values/the number of cases with delay.
@@ -1253,7 +1253,7 @@ class Scenario(Term):
                 - None: Scenario.estimate_delay() calculate automatically
             removed_cols (list[str] or None): list of variables to remove from X dataset or None (indicators used to estimate delay period)
             metric (str): metric name
-            kwargs: keyword arguments of sklearn.model_selection.train_test_split()
+            kwargs: keyword arguments of sklearn.model_selection.train_test_split(), RegressorHandler.fit() and Scenario.fit_accuracy()
 
         Raises:
             covsirphy.UnExecutedError: Scenario.estimate() or Scenario.add() were not performed
@@ -1310,11 +1310,44 @@ class Scenario(Term):
             delay = self._ensure_natural_int(delay, name="delay")
         # Fit regression models
         handler = RegressionHandler(data=data, model=self._model, delay=delay, **kwargs)
-        handler.fit(metric=metric)
+        handler.fit(metric=metric, **find_args(RegressionHandler.fit, **kwargs))
         self._reghandler_dict[name] = handler
+        # Accuracy
+        self.fit_accuracy(name=name, metric=metric, **kwargs)
         # Return information
         return handler.to_dict(metric=metric)
 
+    def _get_fit_handler(self, name="Main"):
+        """
+        Get the instance of RegresionHandler.
+
+        Args:
+            name (str): scenario name
+
+        Raises:
+            covsirphy.UnExecutedError: Scenario.fit() was not performed
+        """
+        if name not in self._reghandler_dict:
+            raise UnExecutedError(f"Scenario.fit(name={name})")
+        return self._reghandler_dict[name]
+
+    def fit_accuracy(self, name="Main", metric="MAPE", show_figure=True, **kwargs):
+        """
+        Create a plot to show the accuracy of forecasting (predicted vs. actual parameter values).
+
+        Args:
+            name (str): scenario name
+            metric (str): metric name, refer to covsirphy.Evaluator.score()
+            show_figure (bool): whether show figure or not
+            kwargs: keyword arguments of RegressionHandler.pred_true_plot()
+        """
+        metric = kwargs.pop("metrics") if "metrics" in kwargs else metric
+        handler = self._get_fit_handler(name=name)
+        # Show predicted vs. actual plot
+        if show_figure:
+            handler.pred_actual_plot(
+                metric=metric, **find_args(RegressionHandler.pred_actual_plot, **kwargs))
+
     def predict(self, days=None, name="Main"):
         """
         Predict parameter values of the future phases using Elastic Net regression with OxCGRT scores,
@@ -1332,11 +1365,8 @@ class Scenario(Term):
         Returns:
             covsirphy.Scenario: self
         """
-        # Arguments
-        if name not in self._reghandler_dict:
-            raise UnExecutedError(f"Scenario.fit(name={name})")
+        handler = self._get_fit_handler(name=name)
         # Prediction with regression model
-        handler = self._reghandler_dict[name]
         df = handler.predict()
         # -> index=end_date (pandas.Timestamp), columns=parameter values
         df.index.name = "end_date"
